# coding: utf-8

"""
    Logto API references

    API references for Logto services. To learn more about how to interact with Logto APIs, see [Interact with Management API](https://docs.logto.io/docs/recipes/interact-with-management-api/).

    The version of the OpenAPI document: Cloud
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field
from typing import Any, ClassVar, Dict, List, Optional
from py_logto.models.api_sign_in_exp_get200_response_password_policy_character_types import ApiSignInExpGet200ResponsePasswordPolicyCharacterTypes
from py_logto.models.api_sign_in_exp_get200_response_password_policy_length import ApiSignInExpGet200ResponsePasswordPolicyLength
from py_logto.models.api_sign_in_exp_get200_response_password_policy_rejects import ApiSignInExpGet200ResponsePasswordPolicyRejects
from typing import Optional, Set
from typing_extensions import Self

class ApiSignInExpGet200ResponsePasswordPolicy(BaseModel):
    """
    Password policies to adjust the password strength requirements.
    """ # noqa: E501
    length: Optional[ApiSignInExpGet200ResponsePasswordPolicyLength] = None
    character_types: Optional[ApiSignInExpGet200ResponsePasswordPolicyCharacterTypes] = Field(default=None, alias="characterTypes")
    rejects: Optional[ApiSignInExpGet200ResponsePasswordPolicyRejects] = None
    __properties: ClassVar[List[str]] = ["length", "characterTypes", "rejects"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ApiSignInExpGet200ResponsePasswordPolicy from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of length
        if self.length:
            _dict['length'] = self.length.to_dict()
        # override the default output from pydantic by calling `to_dict()` of character_types
        if self.character_types:
            _dict['characterTypes'] = self.character_types.to_dict()
        # override the default output from pydantic by calling `to_dict()` of rejects
        if self.rejects:
            _dict['rejects'] = self.rejects.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ApiSignInExpGet200ResponsePasswordPolicy from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "length": ApiSignInExpGet200ResponsePasswordPolicyLength.from_dict(obj["length"]) if obj.get("length") is not None else None,
            "characterTypes": ApiSignInExpGet200ResponsePasswordPolicyCharacterTypes.from_dict(obj["characterTypes"]) if obj.get("characterTypes") is not None else None,
            "rejects": ApiSignInExpGet200ResponsePasswordPolicyRejects.from_dict(obj["rejects"]) if obj.get("rejects") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Logto API references

    API references for Logto services. To learn more about how to interact with Logto APIs, see [Interact with Management API](https://docs.logto.io/docs/recipes/interact-with-management-api/).

    The version of the OpenAPI document: Cloud
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from py_logto.models.api_configs_admin_console_get200_response import ApiConfigsAdminConsoleGet200Response

class TestApiConfigsAdminConsoleGet200Response(unittest.TestCase):
    """ApiConfigsAdminConsoleGet200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiConfigsAdminConsoleGet200Response:
        """Test ApiConfigsAdminConsoleGet200Response
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiConfigsAdminConsoleGet200Response`
        """
        model = ApiConfigsAdminConsoleGet200Response()
        if include_optional:
            return ApiConfigsAdminConsoleGet200Response(
                sign_in_experience_customized = True,
                organization_created = True,
                development_tenant_migration_notification = py_logto.models._api_configs_admin_console_get_200_response_development_tenant_migration_notification._api_configs_admin_console_get_200_response_developmentTenantMigrationNotification(
                    is_paid_tenant = True, 
                    tag = '', 
                    read_at = 1.337, ),
                checked_charge_notification = py_logto.models._api_configs_admin_console_get_200_response_checked_charge_notification._api_configs_admin_console_get_200_response_checkedChargeNotification(
                    token = True, 
                    api_resource = True, 
                    machine_to_machine_app = True, 
                    tenant_member = True, )
            )
        else:
            return ApiConfigsAdminConsoleGet200Response(
                sign_in_experience_customized = True,
                organization_created = True,
        )
        """

    def testApiConfigsAdminConsoleGet200Response(self):
        """Test ApiConfigsAdminConsoleGet200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Logto API references

    API references for Logto services. To learn more about how to interact with Logto APIs, see [Interact with Management API](https://docs.logto.io/docs/recipes/interact-with-management-api/).

    The version of the OpenAPI document: Cloud
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from py_logto.models.api_configs_jwt_customizer_token_type_path_get200_response_one_of_context_sample_user_profile import ApiConfigsJwtCustomizerTokenTypePathGet200ResponseOneOfContextSampleUserProfile
from py_logto.models.api_users_user_id_patch_request_avatar import ApiUsersUserIdPatchRequestAvatar
from typing import Optional, Set
from typing_extensions import Self

class ApiUsersPostRequest(BaseModel):
    """
    User data to create a new user. All properties are optional.
    """ # noqa: E501
    primary_phone: Optional[Annotated[str, Field(strict=True)]] = Field(default=None, description="Primary phone number for the user. It should be unique across all users.", alias="primaryPhone")
    primary_email: Optional[Annotated[str, Field(strict=True)]] = Field(default=None, description="Primary email address for the user. It should be unique across all users.", alias="primaryEmail")
    username: Optional[Annotated[str, Field(strict=True)]] = Field(default=None, description="Username for the user. It should be unique across all users.")
    password: Optional[Annotated[str, Field(min_length=1, strict=True)]] = Field(default=None, description="Plain text password for the user.")
    password_digest: Optional[StrictStr] = Field(default=None, description="In case you already have the password digests and not the passwords, you can use them for the newly created user via this property. The value should be generated with one of the supported algorithms. The algorithm can be specified using the `passwordAlgorithm` property.", alias="passwordDigest")
    password_algorithm: Optional[StrictStr] = Field(default=None, description="The hash algorithm used for the password. It should be one of the supported algorithms: argon2, md5, sha1, sha256. Should the encryption algorithm differ from argon2, it will automatically be upgraded to argon2 upon the user's next sign-in.", alias="passwordAlgorithm")
    name: Optional[StrictStr] = None
    avatar: Optional[ApiUsersUserIdPatchRequestAvatar] = None
    custom_data: Optional[Dict[str, Any]] = Field(default=None, description="arbitrary", alias="customData")
    profile: Optional[ApiConfigsJwtCustomizerTokenTypePathGet200ResponseOneOfContextSampleUserProfile] = None
    __properties: ClassVar[List[str]] = ["primaryPhone", "primaryEmail", "username", "password", "passwordDigest", "passwordAlgorithm", "name", "avatar", "customData", "profile"]

    @field_validator('primary_phone')
    def primary_phone_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if value is None:
            return value

        if not re.match(r"^\d+$", value):
            raise ValueError(r"must validate the regular expression /^\d+$/")
        return value

    @field_validator('primary_email')
    def primary_email_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if value is None:
            return value

        if not re.match(r"^\S+@\S+\.\S+$", value):
            raise ValueError(r"must validate the regular expression /^\S+@\S+\.\S+$/")
        return value

    @field_validator('username')
    def username_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if value is None:
            return value

        if not re.match(r"^[A-Z_a-z]\w*$", value):
            raise ValueError(r"must validate the regular expression /^[A-Z_a-z]\w*$/")
        return value

    @field_validator('password_algorithm')
    def password_algorithm_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['Argon2i', 'SHA1', 'SHA256', 'MD5', 'Bcrypt']):
            raise ValueError("must be one of enum values ('Argon2i', 'SHA1', 'SHA256', 'MD5', 'Bcrypt')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ApiUsersPostRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of avatar
        if self.avatar:
            _dict['avatar'] = self.avatar.to_dict()
        # override the default output from pydantic by calling `to_dict()` of profile
        if self.profile:
            _dict['profile'] = self.profile.to_dict()
        # set to None if avatar (nullable) is None
        # and model_fields_set contains the field
        if self.avatar is None and "avatar" in self.model_fields_set:
            _dict['avatar'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ApiUsersPostRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "primaryPhone": obj.get("primaryPhone"),
            "primaryEmail": obj.get("primaryEmail"),
            "username": obj.get("username"),
            "password": obj.get("password"),
            "passwordDigest": obj.get("passwordDigest"),
            "passwordAlgorithm": obj.get("passwordAlgorithm"),
            "name": obj.get("name"),
            "avatar": ApiUsersUserIdPatchRequestAvatar.from_dict(obj["avatar"]) if obj.get("avatar") is not None else None,
            "customData": obj.get("customData"),
            "profile": ApiConfigsJwtCustomizerTokenTypePathGet200ResponseOneOfContextSampleUserProfile.from_dict(obj["profile"]) if obj.get("profile") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Logto API references

    API references for Logto services. To learn more about how to interact with Logto APIs, see [Interact with Management API](https://docs.logto.io/docs/recipes/interact-with-management-api/).

    The version of the OpenAPI document: Cloud
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from py_logto.api.authn_api import AuthnApi


class TestAuthnApi(unittest.TestCase):
    """AuthnApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AuthnApi()

    def tearDown(self) -> None:
        pass

    def test_api_authn_hasura_get(self) -> None:
        """Test case for api_authn_hasura_get

        Hasura auth hook endpoint
        """
        pass

    def test_api_authn_saml_connector_id_post(self) -> None:
        """Test case for api_authn_saml_connector_id_post

        SAML ACS endpoint (social)
        """
        pass

    def test_api_authn_single_sign_on_saml_connector_id_post(self) -> None:
        """Test case for api_authn_single_sign_on_saml_connector_id_post

        SAML ACS endpoint (SSO)
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Logto API references

    API references for Logto services. To learn more about how to interact with Logto APIs, see [Interact with Management API](https://docs.logto.io/docs/recipes/interact-with-management-api/).

    The version of the OpenAPI document: Cloud
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from py_logto.models.api_applications_get200_response_inner_protected_app_metadata import ApiApplicationsGet200ResponseInnerProtectedAppMetadata

class TestApiApplicationsGet200ResponseInnerProtectedAppMetadata(unittest.TestCase):
    """ApiApplicationsGet200ResponseInnerProtectedAppMetadata unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiApplicationsGet200ResponseInnerProtectedAppMetadata:
        """Test ApiApplicationsGet200ResponseInnerProtectedAppMetadata
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiApplicationsGet200ResponseInnerProtectedAppMetadata`
        """
        model = ApiApplicationsGet200ResponseInnerProtectedAppMetadata()
        if include_optional:
            return ApiApplicationsGet200ResponseInnerProtectedAppMetadata(
                host = '',
                origin = '',
                session_duration = 1.337,
                page_rules = [
                    py_logto.models._api_applications_get_200_response_inner_protected_app_metadata_page_rules_inner._api_applications_get_200_response_inner_protectedAppMetadata_pageRules_inner(
                        path = '', )
                    ],
                custom_domains = [
                    py_logto.models._api_applications_get_200_response_inner_protected_app_metadata_custom_domains_inner._api_applications_get_200_response_inner_protectedAppMetadata_customDomains_inner(
                        domain = '', 
                        status = 'PendingVerification', 
                        error_message = '', 
                        dns_records = [
                            py_logto.models._api_applications_get_200_response_inner_protected_app_metadata_custom_domains_inner_dns_records_inner._api_applications_get_200_response_inner_protectedAppMetadata_customDomains_inner_dnsRecords_inner(
                                name = '', 
                                type = '', 
                                value = '', )
                            ], 
                        cloudflare_data = py_logto.models._api_applications_get_200_response_inner_protected_app_metadata_custom_domains_inner_cloudflare_data._api_applications_get_200_response_inner_protectedAppMetadata_customDomains_inner_cloudflareData(
                            id = '', 
                            status = '', 
                            ssl = py_logto.models._api_applications_get_200_response_inner_protected_app_metadata_custom_domains_inner_cloudflare_data_ssl._api_applications_get_200_response_inner_protectedAppMetadata_customDomains_inner_cloudflareData_ssl(
                                status = '', 
                                validation_errors = [
                                    py_logto.models._api_applications_get_200_response_inner_protected_app_metadata_custom_domains_inner_cloudflare_data_ssl_validation_errors_inner._api_applications_get_200_response_inner_protectedAppMetadata_customDomains_inner_cloudflareData_ssl_validation_errors_inner(
                                        message = '', )
                                    ], ), 
                            verification_errors = [
                                ''
                                ], ), )
                    ]
            )
        else:
            return ApiApplicationsGet200ResponseInnerProtectedAppMetadata(
                host = '',
                origin = '',
                session_duration = 1.337,
                page_rules = [
                    py_logto.models._api_applications_get_200_response_inner_protected_app_metadata_page_rules_inner._api_applications_get_200_response_inner_protectedAppMetadata_pageRules_inner(
                        path = '', )
                    ],
        )
        """

    def testApiApplicationsGet200ResponseInnerProtectedAppMetadata(self):
        """Test ApiApplicationsGet200ResponseInnerProtectedAppMetadata"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Logto API references

    API references for Logto services. To learn more about how to interact with Logto APIs, see [Interact with Management API](https://docs.logto.io/docs/recipes/interact-with-management-api/).

    The version of the OpenAPI document: Cloud
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class ApiOrganizationInvitationsPostRequest(BaseModel):
    """
    ApiOrganizationInvitationsPostRequest
    """ # noqa: E501
    inviter_id: Optional[Any] = Field(default=None, description="The ID of the user who is inviting the user to join the organization.", alias="inviterId")
    invitee: Optional[Any] = Field(default=None, description="The email address of the user to invite to join the organization.")
    organization_id: Optional[Any] = Field(default=None, description="The ID of the organization to invite the user to join.", alias="organizationId")
    expires_at: Optional[Any] = Field(default=None, description="The epoch time in milliseconds when the invitation expires.", alias="expiresAt")
    organization_role_ids: Optional[Any] = Field(default=None, description="The IDs of the organization roles to assign to the user when they accept the invitation.", alias="organizationRoleIds")
    message_payload: Optional[Any] = Field(default=None, description="The message payload for the \"OrganizationInvitation\" template to use when sending the invitation via email. If it is `false`, the invitation will not be sent via email.", alias="messagePayload")
    __properties: ClassVar[List[str]] = ["inviterId", "invitee", "organizationId", "expiresAt", "organizationRoleIds", "messagePayload"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ApiOrganizationInvitationsPostRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if inviter_id (nullable) is None
        # and model_fields_set contains the field
        if self.inviter_id is None and "inviter_id" in self.model_fields_set:
            _dict['inviterId'] = None

        # set to None if invitee (nullable) is None
        # and model_fields_set contains the field
        if self.invitee is None and "invitee" in self.model_fields_set:
            _dict['invitee'] = None

        # set to None if organization_id (nullable) is None
        # and model_fields_set contains the field
        if self.organization_id is None and "organization_id" in self.model_fields_set:
            _dict['organizationId'] = None

        # set to None if expires_at (nullable) is None
        # and model_fields_set contains the field
        if self.expires_at is None and "expires_at" in self.model_fields_set:
            _dict['expiresAt'] = None

        # set to None if organization_role_ids (nullable) is None
        # and model_fields_set contains the field
        if self.organization_role_ids is None and "organization_role_ids" in self.model_fields_set:
            _dict['organizationRoleIds'] = None

        # set to None if message_payload (nullable) is None
        # and model_fields_set contains the field
        if self.message_payload is None and "message_payload" in self.model_fields_set:
            _dict['messagePayload'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ApiOrganizationInvitationsPostRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "inviterId": obj.get("inviterId"),
            "invitee": obj.get("invitee"),
            "organizationId": obj.get("organizationId"),
            "expiresAt": obj.get("expiresAt"),
            "organizationRoleIds": obj.get("organizationRoleIds"),
            "messagePayload": obj.get("messagePayload")
        })
        return _obj





# flake8: noqa

# import apis into api package
from py_logto.api.applications_api import ApplicationsApi
from py_logto.api.audit_logs_api import AuditLogsApi
from py_logto.api.authn_api import AuthnApi
from py_logto.api.configs_api import ConfigsApi
from py_logto.api.connector_factories_api import ConnectorFactoriesApi
from py_logto.api.connectors_api import ConnectorsApi
from py_logto.api.custom_phrases_api import CustomPhrasesApi
from py_logto.api.dashboard_api import DashboardApi
from py_logto.api.domains_api import DomainsApi
from py_logto.api.hooks_api import HooksApi
from py_logto.api.interaction_api import InteractionApi
from py_logto.api.organization_roles_api import OrganizationRolesApi
from py_logto.api.organization_scopes_api import OrganizationScopesApi
from py_logto.api.organizations_api import OrganizationsApi
from py_logto.api.resources_api import ResourcesApi
from py_logto.api.roles_api import RolesApi
from py_logto.api.sso_connector_providers_api import SSOConnectorProvidersApi
from py_logto.api.sso_connectors_api import SSOConnectorsApi
from py_logto.api.sign_in_experience_api import SignInExperienceApi
from py_logto.api.status_api import StatusApi
from py_logto.api.swagger_json_api import SwaggerJsonApi
from py_logto.api.systems_api import SystemsApi
from py_logto.api.user_assets_api import UserAssetsApi
from py_logto.api.users_api import UsersApi
from py_logto.api.verification_codes_api import VerificationCodesApi
from py_logto.api.well_known_api import WellKnownApi
from py_logto.api.default_api import DefaultApi




# coding: utf-8

"""
    Logto API references

    API references for Logto services. To learn more about how to interact with Logto APIs, see [Interact with Management API](https://docs.logto.io/docs/recipes/interact-with-management-api/).

    The version of the OpenAPI document: Cloud
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from py_logto.models.api_users_user_id_patch200_response import ApiUsersUserIdPatch200Response

class TestApiUsersUserIdPatch200Response(unittest.TestCase):
    """ApiUsersUserIdPatch200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiUsersUserIdPatch200Response:
        """Test ApiUsersUserIdPatch200Response
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiUsersUserIdPatch200Response`
        """
        model = ApiUsersUserIdPatch200Response()
        if include_optional:
            return ApiUsersUserIdPatch200Response(
                id = '0',
                username = '',
                primary_email = '',
                primary_phone = '',
                name = '',
                avatar = '',
                custom_data = None,
                identities = {
                    'key' : py_logto.models._api_configs_jwt_customizer__token_type_path__get_200_response_one_of_context_sample_user_identities_value._api_configs_jwt_customizer__tokenTypePath__get_200_response_oneOf_contextSample_user_identities_value(
                        user_id = '', 
                        details = py_logto.models.details.details(), )
                    },
                last_sign_in_at = 1.337,
                created_at = 1.337,
                updated_at = 1.337,
                profile = py_logto.models._api_configs_jwt_customizer__token_type_path__get_200_response_one_of_context_sample_user_profile._api_configs_jwt_customizer__tokenTypePath__get_200_response_oneOf_contextSample_user_profile(
                    family_name = '', 
                    given_name = '', 
                    middle_name = '', 
                    nickname = '', 
                    preferred_username = '', 
                    profile = '', 
                    website = '', 
                    gender = '', 
                    birthdate = '', 
                    zoneinfo = '', 
                    locale = '', 
                    address = py_logto.models._api_configs_jwt_customizer__token_type_path__get_200_response_one_of_context_sample_user_profile_address._api_configs_jwt_customizer__tokenTypePath__get_200_response_oneOf_contextSample_user_profile_address(
                        formatted = '', 
                        street_address = '', 
                        locality = '', 
                        region = '', 
                        postal_code = '', 
                        country = '', ), ),
                application_id = '',
                is_suspended = True,
                has_password = True,
                sso_identities = [
                    py_logto.models._api_users__user_id__get_200_response_sso_identities_inner._api_users__userId__get_200_response_ssoIdentities_inner(
                        id = '0', 
                        user_id = '0', 
                        issuer = '0', 
                        identity_id = '0', 
                        detail = py_logto.models.detail.detail(), 
                        created_at = 1.337, 
                        sso_connector_id = '0', )
                    ]
            )
        else:
            return ApiUsersUserIdPatch200Response(
                id = '0',
                username = '',
                primary_email = '',
                primary_phone = '',
                name = '',
                avatar = '',
                custom_data = None,
                identities = {
                    'key' : py_logto.models._api_configs_jwt_customizer__token_type_path__get_200_response_one_of_context_sample_user_identities_value._api_configs_jwt_customizer__tokenTypePath__get_200_response_oneOf_contextSample_user_identities_value(
                        user_id = '', 
                        details = py_logto.models.details.details(), )
                    },
                last_sign_in_at = 1.337,
                created_at = 1.337,
                updated_at = 1.337,
                profile = py_logto.models._api_configs_jwt_customizer__token_type_path__get_200_response_one_of_context_sample_user_profile._api_configs_jwt_customizer__tokenTypePath__get_200_response_oneOf_contextSample_user_profile(
                    family_name = '', 
                    given_name = '', 
                    middle_name = '', 
                    nickname = '', 
                    preferred_username = '', 
                    profile = '', 
                    website = '', 
                    gender = '', 
                    birthdate = '', 
                    zoneinfo = '', 
                    locale = '', 
                    address = py_logto.models._api_configs_jwt_customizer__token_type_path__get_200_response_one_of_context_sample_user_profile_address._api_configs_jwt_customizer__tokenTypePath__get_200_response_oneOf_contextSample_user_profile_address(
                        formatted = '', 
                        street_address = '', 
                        locality = '', 
                        region = '', 
                        postal_code = '', 
                        country = '', ), ),
                application_id = '',
                is_suspended = True,
        )
        """

    def testApiUsersUserIdPatch200Response(self):
        """Test ApiUsersUserIdPatch200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Logto API references

    API references for Logto services. To learn more about how to interact with Logto APIs, see [Interact with Management API](https://docs.logto.io/docs/recipes/interact-with-management-api/).

    The version of the OpenAPI document: Cloud
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from py_logto.models.api_applications_id_users_user_id_consent_organizations_get200_response import ApiApplicationsIdUsersUserIdConsentOrganizationsGet200Response

class TestApiApplicationsIdUsersUserIdConsentOrganizationsGet200Response(unittest.TestCase):
    """ApiApplicationsIdUsersUserIdConsentOrganizationsGet200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiApplicationsIdUsersUserIdConsentOrganizationsGet200Response:
        """Test ApiApplicationsIdUsersUserIdConsentOrganizationsGet200Response
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiApplicationsIdUsersUserIdConsentOrganizationsGet200Response`
        """
        model = ApiApplicationsIdUsersUserIdConsentOrganizationsGet200Response()
        if include_optional:
            return ApiApplicationsIdUsersUserIdConsentOrganizationsGet200Response(
                organizations = [
                    py_logto.models._api_applications__id__users__user_id__consent_organizations_get_200_response_organizations_inner._api_applications__id__users__userId__consent_organizations_get_200_response_organizations_inner(
                        id = '0', 
                        name = '0', 
                        description = '', 
                        created_at = 1.337, )
                    ]
            )
        else:
            return ApiApplicationsIdUsersUserIdConsentOrganizationsGet200Response(
                organizations = [
                    py_logto.models._api_applications__id__users__user_id__consent_organizations_get_200_response_organizations_inner._api_applications__id__users__userId__consent_organizations_get_200_response_organizations_inner(
                        id = '0', 
                        name = '0', 
                        description = '', 
                        created_at = 1.337, )
                    ],
        )
        """

    def testApiApplicationsIdUsersUserIdConsentOrganizationsGet200Response(self):
        """Test ApiApplicationsIdUsersUserIdConsentOrganizationsGet200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Logto API references

    API references for Logto services. To learn more about how to interact with Logto APIs, see [Interact with Management API](https://docs.logto.io/docs/recipes/interact-with-management-api/).

    The version of the OpenAPI document: Cloud
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from py_logto.models.api_applications_application_id_user_consent_scopes_get200_response import ApiApplicationsApplicationIdUserConsentScopesGet200Response

class TestApiApplicationsApplicationIdUserConsentScopesGet200Response(unittest.TestCase):
    """ApiApplicationsApplicationIdUserConsentScopesGet200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiApplicationsApplicationIdUserConsentScopesGet200Response:
        """Test ApiApplicationsApplicationIdUserConsentScopesGet200Response
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiApplicationsApplicationIdUserConsentScopesGet200Response`
        """
        model = ApiApplicationsApplicationIdUserConsentScopesGet200Response()
        if include_optional:
            return ApiApplicationsApplicationIdUserConsentScopesGet200Response(
                organization_scopes = [
                    py_logto.models._api_applications__application_id__user_consent_scopes_get_200_response_organization_scopes_inner._api_applications__applicationId__user_consent_scopes_get_200_response_organizationScopes_inner(
                        id = '0', 
                        name = '0', 
                        description = '', )
                    ],
                resource_scopes = [
                    py_logto.models._api_applications__application_id__user_consent_scopes_get_200_response_resource_scopes_inner._api_applications__applicationId__user_consent_scopes_get_200_response_resourceScopes_inner(
                        resource = py_logto.models._api_applications__application_id__user_consent_scopes_get_200_response_resource_scopes_inner_resource._api_applications__applicationId__user_consent_scopes_get_200_response_resourceScopes_inner_resource(
                            id = '0', 
                            name = '0', 
                            indicator = '0', ), 
                        scopes = [
                            py_logto.models._api_interaction_consent_get_200_response_missing_resource_scopes_inner_scopes_inner._api_interaction_consent_get_200_response_missingResourceScopes_inner_scopes_inner(
                                id = '0', 
                                name = '0', 
                                description = '', )
                            ], )
                    ],
                user_scopes = [
                    'profile'
                    ]
            )
        else:
            return ApiApplicationsApplicationIdUserConsentScopesGet200Response(
                organization_scopes = [
                    py_logto.models._api_applications__application_id__user_consent_scopes_get_200_response_organization_scopes_inner._api_applications__applicationId__user_consent_scopes_get_200_response_organizationScopes_inner(
                        id = '0', 
                        name = '0', 
                        description = '', )
                    ],
                resource_scopes = [
                    py_logto.models._api_applications__application_id__user_consent_scopes_get_200_response_resource_scopes_inner._api_applications__applicationId__user_consent_scopes_get_200_response_resourceScopes_inner(
                        resource = py_logto.models._api_applications__application_id__user_consent_scopes_get_200_response_resource_scopes_inner_resource._api_applications__applicationId__user_consent_scopes_get_200_response_resourceScopes_inner_resource(
                            id = '0', 
                            name = '0', 
                            indicator = '0', ), 
                        scopes = [
                            py_logto.models._api_interaction_consent_get_200_response_missing_resource_scopes_inner_scopes_inner._api_interaction_consent_get_200_response_missingResourceScopes_inner_scopes_inner(
                                id = '0', 
                                name = '0', 
                                description = '', )
                            ], )
                    ],
                user_scopes = [
                    'profile'
                    ],
        )
        """

    def testApiApplicationsApplicationIdUserConsentScopesGet200Response(self):
        """Test ApiApplicationsApplicationIdUserConsentScopesGet200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Logto API references

    API references for Logto services. To learn more about how to interact with Logto APIs, see [Interact with Management API](https://docs.logto.io/docs/recipes/interact-with-management-api/).

    The version of the OpenAPI document: Cloud
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from py_logto.api.configs_api import ConfigsApi


class TestConfigsApi(unittest.TestCase):
    """ConfigsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ConfigsApi()

    def tearDown(self) -> None:
        pass

    def test_api_configs_admin_console_get(self) -> None:
        """Test case for api_configs_admin_console_get

        Get admin console config
        """
        pass

    def test_api_configs_admin_console_patch(self) -> None:
        """Test case for api_configs_admin_console_patch

        Update admin console config
        """
        pass

    def test_api_configs_jwt_customizer_get(self) -> None:
        """Test case for api_configs_jwt_customizer_get

        Get all JWT customizers
        """
        pass

    def test_api_configs_jwt_customizer_token_type_path_delete(self) -> None:
        """Test case for api_configs_jwt_customizer_token_type_path_delete

        Delete JWT customizer
        """
        pass

    def test_api_configs_jwt_customizer_token_type_path_get(self) -> None:
        """Test case for api_configs_jwt_customizer_token_type_path_get

        Get JWT customizer
        """
        pass

    def test_api_configs_jwt_customizer_token_type_path_patch(self) -> None:
        """Test case for api_configs_jwt_customizer_token_type_path_patch

        Update JWT customizer
        """
        pass

    def test_api_configs_jwt_customizer_token_type_path_put(self) -> None:
        """Test case for api_configs_jwt_customizer_token_type_path_put

        Create or update JWT customizer
        """
        pass

    def test_api_configs_oidc_key_type_get(self) -> None:
        """Test case for api_configs_oidc_key_type_get

        Get OIDC keys
        """
        pass

    def test_api_configs_oidc_key_type_key_id_delete(self) -> None:
        """Test case for api_configs_oidc_key_type_key_id_delete

        Delete OIDC key
        """
        pass

    def test_api_configs_oidc_key_type_rotate_post(self) -> None:
        """Test case for api_configs_oidc_key_type_rotate_post

        Rotate OIDC keys
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Logto API references

    API references for Logto services. To learn more about how to interact with Logto APIs, see [Interact with Management API](https://docs.logto.io/docs/recipes/interact-with-management-api/).

    The version of the OpenAPI document: Cloud
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from py_logto.api.users_api import UsersApi


class TestUsersApi(unittest.TestCase):
    """UsersApi unit test stubs"""

    def setUp(self) -> None:
        self.api = UsersApi()

    def tearDown(self) -> None:
        pass

    def test_api_users_get(self) -> None:
        """Test case for api_users_get

        Get users
        """
        pass

    def test_api_users_post(self) -> None:
        """Test case for api_users_post

        Create user
        """
        pass

    def test_api_users_user_id_custom_data_get(self) -> None:
        """Test case for api_users_user_id_custom_data_get

        Get user custom data
        """
        pass

    def test_api_users_user_id_custom_data_patch(self) -> None:
        """Test case for api_users_user_id_custom_data_patch

        Update user custom data
        """
        pass

    def test_api_users_user_id_delete(self) -> None:
        """Test case for api_users_user_id_delete

        Delete user
        """
        pass

    def test_api_users_user_id_get(self) -> None:
        """Test case for api_users_user_id_get

        Get user
        """
        pass

    def test_api_users_user_id_has_password_get(self) -> None:
        """Test case for api_users_user_id_has_password_get

        Check if user has password
        """
        pass

    def test_api_users_user_id_identities_post(self) -> None:
        """Test case for api_users_user_id_identities_post

        Link social identity to user
        """
        pass

    def test_api_users_user_id_identities_target_delete(self) -> None:
        """Test case for api_users_user_id_identities_target_delete

        Delete social identity from user
        """
        pass

    def test_api_users_user_id_identities_target_put(self) -> None:
        """Test case for api_users_user_id_identities_target_put

        Update social identity of user
        """
        pass

    def test_api_users_user_id_is_suspended_patch(self) -> None:
        """Test case for api_users_user_id_is_suspended_patch

        Update user suspension status
        """
        pass

    def test_api_users_user_id_mfa_verifications_get(self) -> None:
        """Test case for api_users_user_id_mfa_verifications_get

        Get user's MFA verifications
        """
        pass

    def test_api_users_user_id_mfa_verifications_post(self) -> None:
        """Test case for api_users_user_id_mfa_verifications_post

        Create an MFA verification for a user
        """
        pass

    def test_api_users_user_id_mfa_verifications_verification_id_delete(self) -> None:
        """Test case for api_users_user_id_mfa_verifications_verification_id_delete

        Delete an MFA verification for a user
        """
        pass

    def test_api_users_user_id_organizations_get(self) -> None:
        """Test case for api_users_user_id_organizations_get

        Get organizations for a user
        """
        pass

    def test_api_users_user_id_password_patch(self) -> None:
        """Test case for api_users_user_id_password_patch

        Update user password
        """
        pass

    def test_api_users_user_id_password_verify_post(self) -> None:
        """Test case for api_users_user_id_password_verify_post

        Verify user password
        """
        pass

    def test_api_users_user_id_patch(self) -> None:
        """Test case for api_users_user_id_patch

        Update user
        """
        pass

    def test_api_users_user_id_profile_patch(self) -> None:
        """Test case for api_users_user_id_profile_patch

        Update user profile
        """
        pass

    def test_api_users_user_id_roles_get(self) -> None:
        """Test case for api_users_user_id_roles_get

        Get roles for user
        """
        pass

    def test_api_users_user_id_roles_post(self) -> None:
        """Test case for api_users_user_id_roles_post

        Assign roles to user
        """
        pass

    def test_api_users_user_id_roles_put(self) -> None:
        """Test case for api_users_user_id_roles_put

        Update roles for user
        """
        pass

    def test_api_users_user_id_roles_role_id_delete(self) -> None:
        """Test case for api_users_user_id_roles_role_id_delete

        Remove role from user
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Logto API references

    API references for Logto services. To learn more about how to interact with Logto APIs, see [Interact with Management API](https://docs.logto.io/docs/recipes/interact-with-management-api/).

    The version of the OpenAPI document: Cloud
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictFloat, StrictInt
from typing import Any, ClassVar, Dict, List, Union
from typing_extensions import Annotated
from py_logto.models.api_configs_jwt_customizer_token_type_path_get200_response_one_of_context_sample_user_identities_value import ApiConfigsJwtCustomizerTokenTypePathGet200ResponseOneOfContextSampleUserIdentitiesValue
from py_logto.models.api_configs_jwt_customizer_token_type_path_get200_response_one_of_context_sample_user_profile import ApiConfigsJwtCustomizerTokenTypePathGet200ResponseOneOfContextSampleUserProfile
from py_logto.models.api_users_user_id_get200_response_sso_identities_inner import ApiUsersUserIdGet200ResponseSsoIdentitiesInner
from typing import Optional, Set
from typing_extensions import Self


class ApiUsersUserIdGet200Response(BaseModel):
    """
    ApiUsersUserIdGet200Response
    """ # noqa: E501
    id: Annotated[str, Field(min_length=1, strict=True, max_length=12)]
    username: Optional[Annotated[str, Field(strict=True, max_length=128)]]
    primary_email: Optional[Annotated[str, Field(strict=True, max_length=128)]] = Field(alias="primaryEmail")
    primary_phone: Optional[Annotated[str, Field(strict=True, max_length=128)]] = Field(alias="primaryPhone")
    name: Optional[Annotated[str, Field(strict=True, max_length=128)]]
    avatar: Optional[Annotated[str, Field(strict=True, max_length=2048)]]
    custom_data: Dict[str, Any] = Field(description="arbitrary", alias="customData")
    identities: Dict[str, ApiConfigsJwtCustomizerTokenTypePathGet200ResponseOneOfContextSampleUserIdentitiesValue]
    last_sign_in_at: Optional[Union[StrictFloat, StrictInt]] = Field(alias="lastSignInAt")
    created_at: Union[StrictFloat, StrictInt] = Field(alias="createdAt")
    updated_at: Union[StrictFloat, StrictInt] = Field(alias="updatedAt")
    profile: ApiConfigsJwtCustomizerTokenTypePathGet200ResponseOneOfContextSampleUserProfile
    application_id: Optional[Annotated[str, Field(strict=True, max_length=21)]] = Field(alias="applicationId")
    is_suspended: StrictBool = Field(alias="isSuspended")
    has_password: Optional[StrictBool] = Field(default=None, alias="hasPassword")
    sso_identities: Optional[List[ApiUsersUserIdGet200ResponseSsoIdentitiesInner]] = Field(default=None, description="List of SSO identities associated with the user. Only available when the `includeSsoIdentities` query parameter is provided with a truthy value.", alias="ssoIdentities")
    __properties: ClassVar[List[str]] = ["id", "username", "primaryEmail", "primaryPhone", "name", "avatar", "customData", "identities", "lastSignInAt", "createdAt", "updatedAt", "profile", "applicationId", "isSuspended", "hasPassword", "ssoIdentities"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ApiUsersUserIdGet200Response from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each value in identities (dict)
        _field_dict = {}
        if self.identities:
            for _key in self.identities:
                if self.identities[_key]:
                    _field_dict[_key] = self.identities[_key].to_dict()
            _dict['identities'] = _field_dict
        # override the default output from pydantic by calling `to_dict()` of profile
        if self.profile:
            _dict['profile'] = self.profile.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in sso_identities (list)
        _items = []
        if self.sso_identities:
            for _item in self.sso_identities:
                if _item:
                    _items.append(_item.to_dict())
            _dict['ssoIdentities'] = _items
        # set to None if username (nullable) is None
        # and model_fields_set contains the field
        if self.username is None and "username" in self.model_fields_set:
            _dict['username'] = None

        # set to None if primary_email (nullable) is None
        # and model_fields_set contains the field
        if self.primary_email is None and "primary_email" in self.model_fields_set:
            _dict['primaryEmail'] = None

        # set to None if primary_phone (nullable) is None
        # and model_fields_set contains the field
        if self.primary_phone is None and "primary_phone" in self.model_fields_set:
            _dict['primaryPhone'] = None

        # set to None if name (nullable) is None
        # and model_fields_set contains the field
        if self.name is None and "name" in self.model_fields_set:
            _dict['name'] = None

        # set to None if avatar (nullable) is None
        # and model_fields_set contains the field
        if self.avatar is None and "avatar" in self.model_fields_set:
            _dict['avatar'] = None

        # set to None if last_sign_in_at (nullable) is None
        # and model_fields_set contains the field
        if self.last_sign_in_at is None and "last_sign_in_at" in self.model_fields_set:
            _dict['lastSignInAt'] = None

        # set to None if application_id (nullable) is None
        # and model_fields_set contains the field
        if self.application_id is None and "application_id" in self.model_fields_set:
            _dict['applicationId'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ApiUsersUserIdGet200Response from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "username": obj.get("username"),
            "primaryEmail": obj.get("primaryEmail"),
            "primaryPhone": obj.get("primaryPhone"),
            "name": obj.get("name"),
            "avatar": obj.get("avatar"),
            "customData": obj.get("customData"),
            "identities": dict(
                (_k, ApiConfigsJwtCustomizerTokenTypePathGet200ResponseOneOfContextSampleUserIdentitiesValue.from_dict(_v))
                for _k, _v in obj["identities"].items()
            )
            if obj.get("identities") is not None
            else None,
            "lastSignInAt": obj.get("lastSignInAt"),
            "createdAt": obj.get("createdAt"),
            "updatedAt": obj.get("updatedAt"),
            "profile": ApiConfigsJwtCustomizerTokenTypePathGet200ResponseOneOfContextSampleUserProfile.from_dict(obj["profile"]) if obj.get("profile") is not None else None,
            "applicationId": obj.get("applicationId"),
            "isSuspended": obj.get("isSuspended"),
            "hasPassword": obj.get("hasPassword"),
            "ssoIdentities": [ApiUsersUserIdGet200ResponseSsoIdentitiesInner.from_dict(_item) for _item in obj["ssoIdentities"]] if obj.get("ssoIdentities") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Logto API references

    API references for Logto services. To learn more about how to interact with Logto APIs, see [Interact with Management API](https://docs.logto.io/docs/recipes/interact-with-management-api/).

    The version of the OpenAPI document: Cloud
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from py_logto.models.api_interaction_consent_get200_response import ApiInteractionConsentGet200Response

class TestApiInteractionConsentGet200Response(unittest.TestCase):
    """ApiInteractionConsentGet200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiInteractionConsentGet200Response:
        """Test ApiInteractionConsentGet200Response
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiInteractionConsentGet200Response`
        """
        model = ApiInteractionConsentGet200Response()
        if include_optional:
            return ApiInteractionConsentGet200Response(
                application = py_logto.models._api_interaction_consent_get_200_response_application._api_interaction_consent_get_200_response_application(
                    id = '0', 
                    name = '0', 
                    branding = py_logto.models._api_interaction_consent_get_200_response_application_branding._api_interaction_consent_get_200_response_application_branding(
                        logo_url = '', 
                        dark_logo_url = '', 
                        favicon = '', ), 
                    display_name = '', 
                    privacy_policy_url = '', 
                    terms_of_use_url = '', ),
                user = py_logto.models._api_interaction_consent_get_200_response_user._api_interaction_consent_get_200_response_user(
                    id = '0', 
                    name = '', 
                    avatar = '', 
                    username = '', 
                    primary_email = '', 
                    primary_phone = '', ),
                organizations = [
                    py_logto.models._api_interaction_consent_get_200_response_organizations_inner._api_interaction_consent_get_200_response_organizations_inner(
                        id = '0', 
                        name = '0', )
                    ],
                missing_oidc_scope = [
                    ''
                    ],
                missing_resource_scopes = [
                    py_logto.models._api_interaction_consent_get_200_response_missing_resource_scopes_inner._api_interaction_consent_get_200_response_missingResourceScopes_inner(
                        resource = py_logto.models._api_interaction_consent_get_200_response_missing_resource_scopes_inner_resource._api_interaction_consent_get_200_response_missingResourceScopes_inner_resource(
                            name = '0', 
                            id = '', ), 
                        scopes = [
                            py_logto.models._api_interaction_consent_get_200_response_missing_resource_scopes_inner_scopes_inner._api_interaction_consent_get_200_response_missingResourceScopes_inner_scopes_inner(
                                id = '0', 
                                name = '0', 
                                description = '', )
                            ], )
                    ],
                redirect_uri = ''
            )
        else:
            return ApiInteractionConsentGet200Response(
                application = py_logto.models._api_interaction_consent_get_200_response_application._api_interaction_consent_get_200_response_application(
                    id = '0', 
                    name = '0', 
                    branding = py_logto.models._api_interaction_consent_get_200_response_application_branding._api_interaction_consent_get_200_response_application_branding(
                        logo_url = '', 
                        dark_logo_url = '', 
                        favicon = '', ), 
                    display_name = '', 
                    privacy_policy_url = '', 
                    terms_of_use_url = '', ),
                user = py_logto.models._api_interaction_consent_get_200_response_user._api_interaction_consent_get_200_response_user(
                    id = '0', 
                    name = '', 
                    avatar = '', 
                    username = '', 
                    primary_email = '', 
                    primary_phone = '', ),
                redirect_uri = '',
        )
        """

    def testApiInteractionConsentGet200Response(self):
        """Test ApiInteractionConsentGet200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Logto API references

    API references for Logto services. To learn more about how to interact with Logto APIs, see [Interact with Management API](https://docs.logto.io/docs/recipes/interact-with-management-api/).

    The version of the OpenAPI document: Cloud
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from py_logto.api.roles_api import RolesApi


class TestRolesApi(unittest.TestCase):
    """RolesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = RolesApi()

    def tearDown(self) -> None:
        pass

    def test_api_roles_get(self) -> None:
        """Test case for api_roles_get

        Get roles
        """
        pass

    def test_api_roles_id_applications_application_id_delete(self) -> None:
        """Test case for api_roles_id_applications_application_id_delete

        Remove role from application
        """
        pass

    def test_api_roles_id_applications_get(self) -> None:
        """Test case for api_roles_id_applications_get

        Get role applications
        """
        pass

    def test_api_roles_id_applications_post(self) -> None:
        """Test case for api_roles_id_applications_post

        Assign role to applications
        """
        pass

    def test_api_roles_id_delete(self) -> None:
        """Test case for api_roles_id_delete

        Delete role
        """
        pass

    def test_api_roles_id_get(self) -> None:
        """Test case for api_roles_id_get

        Get role
        """
        pass

    def test_api_roles_id_patch(self) -> None:
        """Test case for api_roles_id_patch

        Update role
        """
        pass

    def test_api_roles_id_scopes_get(self) -> None:
        """Test case for api_roles_id_scopes_get

        Get role scopes
        """
        pass

    def test_api_roles_id_scopes_post(self) -> None:
        """Test case for api_roles_id_scopes_post

        Link scopes to role
        """
        pass

    def test_api_roles_id_scopes_scope_id_delete(self) -> None:
        """Test case for api_roles_id_scopes_scope_id_delete

        Unlink scope from role
        """
        pass

    def test_api_roles_id_users_get(self) -> None:
        """Test case for api_roles_id_users_get

        Get role users
        """
        pass

    def test_api_roles_id_users_post(self) -> None:
        """Test case for api_roles_id_users_post

        Assign role to users
        """
        pass

    def test_api_roles_id_users_user_id_delete(self) -> None:
        """Test case for api_roles_id_users_user_id_delete

        Remove role from user
        """
        pass

    def test_api_roles_post(self) -> None:
        """Test case for api_roles_post

        Create a role
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Logto API references

    API references for Logto services. To learn more about how to interact with Logto APIs, see [Interact with Management API](https://docs.logto.io/docs/recipes/interact-with-management-api/).

    The version of the OpenAPI document: Cloud
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from py_logto.models.api_applications_get200_response_inner_protected_app_metadata_custom_domains_inner import ApiApplicationsGet200ResponseInnerProtectedAppMetadataCustomDomainsInner

class TestApiApplicationsGet200ResponseInnerProtectedAppMetadataCustomDomainsInner(unittest.TestCase):
    """ApiApplicationsGet200ResponseInnerProtectedAppMetadataCustomDomainsInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiApplicationsGet200ResponseInnerProtectedAppMetadataCustomDomainsInner:
        """Test ApiApplicationsGet200ResponseInnerProtectedAppMetadataCustomDomainsInner
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiApplicationsGet200ResponseInnerProtectedAppMetadataCustomDomainsInner`
        """
        model = ApiApplicationsGet200ResponseInnerProtectedAppMetadataCustomDomainsInner()
        if include_optional:
            return ApiApplicationsGet200ResponseInnerProtectedAppMetadataCustomDomainsInner(
                domain = '',
                status = 'PendingVerification',
                error_message = '',
                dns_records = [
                    py_logto.models._api_applications_get_200_response_inner_protected_app_metadata_custom_domains_inner_dns_records_inner._api_applications_get_200_response_inner_protectedAppMetadata_customDomains_inner_dnsRecords_inner(
                        name = '', 
                        type = '', 
                        value = '', )
                    ],
                cloudflare_data = py_logto.models._api_applications_get_200_response_inner_protected_app_metadata_custom_domains_inner_cloudflare_data._api_applications_get_200_response_inner_protectedAppMetadata_customDomains_inner_cloudflareData(
                    id = '', 
                    status = '', 
                    ssl = py_logto.models._api_applications_get_200_response_inner_protected_app_metadata_custom_domains_inner_cloudflare_data_ssl._api_applications_get_200_response_inner_protectedAppMetadata_customDomains_inner_cloudflareData_ssl(
                        status = '', 
                        validation_errors = [
                            py_logto.models._api_applications_get_200_response_inner_protected_app_metadata_custom_domains_inner_cloudflare_data_ssl_validation_errors_inner._api_applications_get_200_response_inner_protectedAppMetadata_customDomains_inner_cloudflareData_ssl_validation_errors_inner(
                                message = '', )
                            ], ), 
                    verification_errors = [
                        ''
                        ], )
            )
        else:
            return ApiApplicationsGet200ResponseInnerProtectedAppMetadataCustomDomainsInner(
                domain = '',
                status = 'PendingVerification',
                error_message = '',
                dns_records = [
                    py_logto.models._api_applications_get_200_response_inner_protected_app_metadata_custom_domains_inner_dns_records_inner._api_applications_get_200_response_inner_protectedAppMetadata_customDomains_inner_dnsRecords_inner(
                        name = '', 
                        type = '', 
                        value = '', )
                    ],
                cloudflare_data = py_logto.models._api_applications_get_200_response_inner_protected_app_metadata_custom_domains_inner_cloudflare_data._api_applications_get_200_response_inner_protectedAppMetadata_customDomains_inner_cloudflareData(
                    id = '', 
                    status = '', 
                    ssl = py_logto.models._api_applications_get_200_response_inner_protected_app_metadata_custom_domains_inner_cloudflare_data_ssl._api_applications_get_200_response_inner_protectedAppMetadata_customDomains_inner_cloudflareData_ssl(
                        status = '', 
                        validation_errors = [
                            py_logto.models._api_applications_get_200_response_inner_protected_app_metadata_custom_domains_inner_cloudflare_data_ssl_validation_errors_inner._api_applications_get_200_response_inner_protectedAppMetadata_customDomains_inner_cloudflareData_ssl_validation_errors_inner(
                                message = '', )
                            ], ), 
                    verification_errors = [
                        ''
                        ], ),
        )
        """

    def testApiApplicationsGet200ResponseInnerProtectedAppMetadataCustomDomainsInner(self):
        """Test ApiApplicationsGet200ResponseInnerProtectedAppMetadataCustomDomainsInner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Logto API references

    API references for Logto services. To learn more about how to interact with Logto APIs, see [Interact with Management API](https://docs.logto.io/docs/recipes/interact-with-management-api/).

    The version of the OpenAPI document: Cloud
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictFloat, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing_extensions import Annotated
from py_logto.models.api_connectors_get200_response_inner_form_items_inner import ApiConnectorsGet200ResponseInnerFormItemsInner
from py_logto.models.api_connectors_get200_response_inner_metadata import ApiConnectorsGet200ResponseInnerMetadata
from typing import Optional, Set
from typing_extensions import Self

class ApiConnectorsGet200ResponseInner(BaseModel):
    """
    ApiConnectorsGet200ResponseInner
    """ # noqa: E501
    id: StrictStr
    sync_profile: StrictBool = Field(alias="syncProfile")
    config: Dict[str, Any] = Field(description="arbitrary")
    metadata: ApiConnectorsGet200ResponseInnerMetadata
    connector_id: Annotated[str, Field(min_length=1, strict=True, max_length=128)] = Field(alias="connectorId")
    target: StrictStr
    name: Dict[str, Any] = Field(description="Validator function")
    description: Dict[str, Any] = Field(description="Validator function")
    logo: StrictStr
    logo_dark: Optional[StrictStr] = Field(alias="logoDark")
    readme: StrictStr
    config_template: Optional[StrictStr] = Field(default=None, alias="configTemplate")
    form_items: Optional[List[ApiConnectorsGet200ResponseInnerFormItemsInner]] = Field(default=None, alias="formItems")
    platform: Optional[StrictStr]
    is_standard: Optional[StrictBool] = Field(default=None, alias="isStandard")
    type: StrictStr
    is_demo: Optional[StrictBool] = Field(default=None, alias="isDemo")
    extra_info: Optional[Dict[str, Any]] = Field(default=None, alias="extraInfo")
    usage: Optional[Union[StrictFloat, StrictInt]] = None
    __properties: ClassVar[List[str]] = ["id", "syncProfile", "config", "metadata", "connectorId", "target", "name", "description", "logo", "logoDark", "readme", "configTemplate", "formItems", "platform", "isStandard", "type", "isDemo", "extraInfo", "usage"]

    @field_validator('platform')
    def platform_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['Native', 'Universal', 'Web']):
            raise ValueError("must be one of enum values ('Native', 'Universal', 'Web')")
        return value

    @field_validator('type')
    def type_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(['Email', 'Sms', 'Social']):
            raise ValueError("must be one of enum values ('Email', 'Sms', 'Social')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ApiConnectorsGet200ResponseInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of metadata
        if self.metadata:
            _dict['metadata'] = self.metadata.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in form_items (list)
        _items = []
        if self.form_items:
            for _item in self.form_items:
                if _item:
                    _items.append(_item.to_dict())
            _dict['formItems'] = _items
        # set to None if logo_dark (nullable) is None
        # and model_fields_set contains the field
        if self.logo_dark is None and "logo_dark" in self.model_fields_set:
            _dict['logoDark'] = None

        # set to None if platform (nullable) is None
        # and model_fields_set contains the field
        if self.platform is None and "platform" in self.model_fields_set:
            _dict['platform'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ApiConnectorsGet200ResponseInner from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "syncProfile": obj.get("syncProfile"),
            "config": obj.get("config"),
            "metadata": ApiConnectorsGet200ResponseInnerMetadata.from_dict(obj["metadata"]) if obj.get("metadata") is not None else None,
            "connectorId": obj.get("connectorId"),
            "target": obj.get("target"),
            "name": obj.get("name"),
            "description": obj.get("description"),
            "logo": obj.get("logo"),
            "logoDark": obj.get("logoDark"),
            "readme": obj.get("readme"),
            "configTemplate": obj.get("configTemplate"),
            "formItems": [ApiConnectorsGet200ResponseInnerFormItemsInner.from_dict(_item) for _item in obj["formItems"]] if obj.get("formItems") is not None else None,
            "platform": obj.get("platform"),
            "isStandard": obj.get("isStandard"),
            "type": obj.get("type"),
            "isDemo": obj.get("isDemo"),
            "extraInfo": obj.get("extraInfo"),
            "usage": obj.get("usage")
        })
        return _obj





# coding: utf-8

"""
    Logto API references

    API references for Logto services. To learn more about how to interact with Logto APIs, see [Interact with Management API](https://docs.logto.io/docs/recipes/interact-with-management-api/).

    The version of the OpenAPI document: Cloud
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from py_logto.models.api_hooks_id_patch200_response import ApiHooksIdPatch200Response

class TestApiHooksIdPatch200Response(unittest.TestCase):
    """ApiHooksIdPatch200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiHooksIdPatch200Response:
        """Test ApiHooksIdPatch200Response
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiHooksIdPatch200Response`
        """
        model = ApiHooksIdPatch200Response()
        if include_optional:
            return ApiHooksIdPatch200Response(
                id = '0',
                name = '',
                event = 'PostRegister',
                events = [
                    'PostRegister'
                    ],
                config = py_logto.models._api_hooks_get_200_response_inner_config._api_hooks_get_200_response_inner_config(
                    url = '', 
                    headers = {
                        'key' : ''
                        }, 
                    retries = 1.337, ),
                signing_key = '',
                enabled = True,
                created_at = 1.337
            )
        else:
            return ApiHooksIdPatch200Response(
                id = '0',
                name = '',
                event = 'PostRegister',
                events = [
                    'PostRegister'
                    ],
                config = py_logto.models._api_hooks_get_200_response_inner_config._api_hooks_get_200_response_inner_config(
                    url = '', 
                    headers = {
                        'key' : ''
                        }, 
                    retries = 1.337, ),
                signing_key = '',
                enabled = True,
                created_at = 1.337,
        )
        """

    def testApiHooksIdPatch200Response(self):
        """Test ApiHooksIdPatch200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Logto API references

    API references for Logto services. To learn more about how to interact with Logto APIs, see [Interact with Management API](https://docs.logto.io/docs/recipes/interact-with-management-api/).

    The version of the OpenAPI document: Cloud
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from py_logto.models.api_resources_get200_response_inner import ApiResourcesGet200ResponseInner

class TestApiResourcesGet200ResponseInner(unittest.TestCase):
    """ApiResourcesGet200ResponseInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiResourcesGet200ResponseInner:
        """Test ApiResourcesGet200ResponseInner
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiResourcesGet200ResponseInner`
        """
        model = ApiResourcesGet200ResponseInner()
        if include_optional:
            return ApiResourcesGet200ResponseInner(
                id = '0',
                name = '0',
                indicator = '0',
                is_default = True,
                access_token_ttl = 1.337,
                scopes = [
                    py_logto.models._api_resources_get_200_response_inner_scopes_inner._api_resources_get_200_response_inner_scopes_inner(
                        id = '0', 
                        resource_id = '0', 
                        name = '0', 
                        description = '', 
                        created_at = 1.337, )
                    ]
            )
        else:
            return ApiResourcesGet200ResponseInner(
                id = '0',
                name = '0',
                indicator = '0',
                is_default = True,
                access_token_ttl = 1.337,
        )
        """

    def testApiResourcesGet200ResponseInner(self):
        """Test ApiResourcesGet200ResponseInner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Logto API references

    API references for Logto services. To learn more about how to interact with Logto APIs, see [Interact with Management API](https://docs.logto.io/docs/recipes/interact-with-management-api/).

    The version of the OpenAPI document: Cloud
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from py_logto.models.api_interaction_verification_verification_code_post_request import ApiInteractionVerificationVerificationCodePostRequest
from py_logto.models.api_verification_codes_verify_post_request import ApiVerificationCodesVerifyPostRequest

from py_logto.api_client import ApiClient, RequestSerialized
from py_logto.api_response import ApiResponse
from py_logto.rest import RESTResponseType


class VerificationCodesApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def api_verification_codes_post(
        self,
        api_interaction_verification_verification_code_post_request: ApiInteractionVerificationVerificationCodePostRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """Request and send a verification code

        Request a verification code for the provided identifier (email/phone). if you're using email as the identifier, you need to setup your email connector first. if you're using phone as the identifier, you need to setup your SMS connector first.

        :param api_interaction_verification_verification_code_post_request: (required)
        :type api_interaction_verification_verification_code_post_request: ApiInteractionVerificationVerificationCodePostRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_verification_codes_post_serialize(
            api_interaction_verification_verification_code_post_request=api_interaction_verification_verification_code_post_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
            '400': None,
            '401': None,
            '403': None,
            '501': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def api_verification_codes_post_with_http_info(
        self,
        api_interaction_verification_verification_code_post_request: ApiInteractionVerificationVerificationCodePostRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """Request and send a verification code

        Request a verification code for the provided identifier (email/phone). if you're using email as the identifier, you need to setup your email connector first. if you're using phone as the identifier, you need to setup your SMS connector first.

        :param api_interaction_verification_verification_code_post_request: (required)
        :type api_interaction_verification_verification_code_post_request: ApiInteractionVerificationVerificationCodePostRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_verification_codes_post_serialize(
            api_interaction_verification_verification_code_post_request=api_interaction_verification_verification_code_post_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
            '400': None,
            '401': None,
            '403': None,
            '501': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def api_verification_codes_post_without_preload_content(
        self,
        api_interaction_verification_verification_code_post_request: ApiInteractionVerificationVerificationCodePostRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Request and send a verification code

        Request a verification code for the provided identifier (email/phone). if you're using email as the identifier, you need to setup your email connector first. if you're using phone as the identifier, you need to setup your SMS connector first.

        :param api_interaction_verification_verification_code_post_request: (required)
        :type api_interaction_verification_verification_code_post_request: ApiInteractionVerificationVerificationCodePostRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_verification_codes_post_serialize(
            api_interaction_verification_verification_code_post_request=api_interaction_verification_verification_code_post_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
            '400': None,
            '401': None,
            '403': None,
            '501': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _api_verification_codes_post_serialize(
        self,
        api_interaction_verification_verification_code_post_request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if api_interaction_verification_verification_code_post_request is not None:
            _body_params = api_interaction_verification_verification_code_post_request



        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/api/verification-codes',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def api_verification_codes_verify_post(
        self,
        api_verification_codes_verify_post_request: ApiVerificationCodesVerifyPostRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """Verify a verification code

        Verify a verification code for a specified identifier. if you're using email as the identifier, you need to setup your email connector first. if you're using phone as the identifier, you need to setup your SMS connector first.

        :param api_verification_codes_verify_post_request: (required)
        :type api_verification_codes_verify_post_request: ApiVerificationCodesVerifyPostRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_verification_codes_verify_post_serialize(
            api_verification_codes_verify_post_request=api_verification_codes_verify_post_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
            '400': None,
            '401': None,
            '403': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def api_verification_codes_verify_post_with_http_info(
        self,
        api_verification_codes_verify_post_request: ApiVerificationCodesVerifyPostRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """Verify a verification code

        Verify a verification code for a specified identifier. if you're using email as the identifier, you need to setup your email connector first. if you're using phone as the identifier, you need to setup your SMS connector first.

        :param api_verification_codes_verify_post_request: (required)
        :type api_verification_codes_verify_post_request: ApiVerificationCodesVerifyPostRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_verification_codes_verify_post_serialize(
            api_verification_codes_verify_post_request=api_verification_codes_verify_post_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
            '400': None,
            '401': None,
            '403': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def api_verification_codes_verify_post_without_preload_content(
        self,
        api_verification_codes_verify_post_request: ApiVerificationCodesVerifyPostRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Verify a verification code

        Verify a verification code for a specified identifier. if you're using email as the identifier, you need to setup your email connector first. if you're using phone as the identifier, you need to setup your SMS connector first.

        :param api_verification_codes_verify_post_request: (required)
        :type api_verification_codes_verify_post_request: ApiVerificationCodesVerifyPostRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_verification_codes_verify_post_serialize(
            api_verification_codes_verify_post_request=api_verification_codes_verify_post_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
            '400': None,
            '401': None,
            '403': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _api_verification_codes_verify_post_serialize(
        self,
        api_verification_codes_verify_post_request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if api_verification_codes_verify_post_request is not None:
            _body_params = api_verification_codes_verify_post_request



        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/api/verification-codes/verify',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    Logto API references

    API references for Logto services. To learn more about how to interact with Logto APIs, see [Interact with Management API](https://docs.logto.io/docs/recipes/interact-with-management-api/).

    The version of the OpenAPI document: Cloud
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from py_logto.api.organization_roles_api import OrganizationRolesApi


class TestOrganizationRolesApi(unittest.TestCase):
    """OrganizationRolesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = OrganizationRolesApi()

    def tearDown(self) -> None:
        pass

    def test_api_organization_roles_get(self) -> None:
        """Test case for api_organization_roles_get

        Get organization roles
        """
        pass

    def test_api_organization_roles_id_delete(self) -> None:
        """Test case for api_organization_roles_id_delete

        Delete organization role
        """
        pass

    def test_api_organization_roles_id_get(self) -> None:
        """Test case for api_organization_roles_id_get

        Get organization role
        """
        pass

    def test_api_organization_roles_id_patch(self) -> None:
        """Test case for api_organization_roles_id_patch

        Update organization role
        """
        pass

    def test_api_organization_roles_id_scopes_get(self) -> None:
        """Test case for api_organization_roles_id_scopes_get

        Get organization role scopes
        """
        pass

    def test_api_organization_roles_id_scopes_organization_scope_id_delete(self) -> None:
        """Test case for api_organization_roles_id_scopes_organization_scope_id_delete

        Remove organization scope
        """
        pass

    def test_api_organization_roles_id_scopes_post(self) -> None:
        """Test case for api_organization_roles_id_scopes_post

        Assign organization scopes to organization role
        """
        pass

    def test_api_organization_roles_id_scopes_put(self) -> None:
        """Test case for api_organization_roles_id_scopes_put

        Replace organization scopes for organization role
        """
        pass

    def test_api_organization_roles_post(self) -> None:
        """Test case for api_organization_roles_post

        Create an organization role
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Logto API references

    API references for Logto services. To learn more about how to interact with Logto APIs, see [Interact with Management API](https://docs.logto.io/docs/recipes/interact-with-management-api/).

    The version of the OpenAPI document: Cloud
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from py_logto.api.interaction_api import InteractionApi


class TestInteractionApi(unittest.TestCase):
    """InteractionApi unit test stubs"""

    def setUp(self) -> None:
        self.api = InteractionApi()

    def tearDown(self) -> None:
        pass

    def test_api_interaction_bind_mfa_post(self) -> None:
        """Test case for api_interaction_bind_mfa_post

        """
        pass

    def test_api_interaction_consent_get(self) -> None:
        """Test case for api_interaction_consent_get

        """
        pass

    def test_api_interaction_consent_post(self) -> None:
        """Test case for api_interaction_consent_post

        """
        pass

    def test_api_interaction_delete(self) -> None:
        """Test case for api_interaction_delete

        """
        pass

    def test_api_interaction_event_put(self) -> None:
        """Test case for api_interaction_event_put

        """
        pass

    def test_api_interaction_identifiers_patch(self) -> None:
        """Test case for api_interaction_identifiers_patch

        """
        pass

    def test_api_interaction_mfa_put(self) -> None:
        """Test case for api_interaction_mfa_put

        """
        pass

    def test_api_interaction_mfa_skipped_put(self) -> None:
        """Test case for api_interaction_mfa_skipped_put

        """
        pass

    def test_api_interaction_profile_delete(self) -> None:
        """Test case for api_interaction_profile_delete

        """
        pass

    def test_api_interaction_profile_patch(self) -> None:
        """Test case for api_interaction_profile_patch

        """
        pass

    def test_api_interaction_profile_put(self) -> None:
        """Test case for api_interaction_profile_put

        """
        pass

    def test_api_interaction_put(self) -> None:
        """Test case for api_interaction_put

        """
        pass

    def test_api_interaction_single_sign_on_connector_id_authentication_post(self) -> None:
        """Test case for api_interaction_single_sign_on_connector_id_authentication_post

        """
        pass

    def test_api_interaction_single_sign_on_connector_id_authorization_url_post(self) -> None:
        """Test case for api_interaction_single_sign_on_connector_id_authorization_url_post

        """
        pass

    def test_api_interaction_single_sign_on_connector_id_registration_post(self) -> None:
        """Test case for api_interaction_single_sign_on_connector_id_registration_post

        """
        pass

    def test_api_interaction_single_sign_on_connectors_get(self) -> None:
        """Test case for api_interaction_single_sign_on_connectors_get

        """
        pass

    def test_api_interaction_submit_post(self) -> None:
        """Test case for api_interaction_submit_post

        """
        pass

    def test_api_interaction_verification_social_authorization_uri_post(self) -> None:
        """Test case for api_interaction_verification_social_authorization_uri_post

        """
        pass

    def test_api_interaction_verification_totp_post(self) -> None:
        """Test case for api_interaction_verification_totp_post

        """
        pass

    def test_api_interaction_verification_verification_code_post(self) -> None:
        """Test case for api_interaction_verification_verification_code_post

        """
        pass

    def test_api_interaction_verification_webauthn_authentication_post(self) -> None:
        """Test case for api_interaction_verification_webauthn_authentication_post

        """
        pass

    def test_api_interaction_verification_webauthn_registration_post(self) -> None:
        """Test case for api_interaction_verification_webauthn_registration_post

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Logto API references

    API references for Logto services. To learn more about how to interact with Logto APIs, see [Interact with Management API](https://docs.logto.io/docs/recipes/interact-with-management-api/).

    The version of the OpenAPI document: Cloud
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from py_logto.models.api_verification_codes_verify_post_request import ApiVerificationCodesVerifyPostRequest

class TestApiVerificationCodesVerifyPostRequest(unittest.TestCase):
    """ApiVerificationCodesVerifyPostRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiVerificationCodesVerifyPostRequest:
        """Test ApiVerificationCodesVerifyPostRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiVerificationCodesVerifyPostRequest`
        """
        model = ApiVerificationCodesVerifyPostRequest()
        if include_optional:
            return ApiVerificationCodesVerifyPostRequest(
                email = 'k@?x!u'K}qz^sEC)lJ*=-jQ+'6`%cClu,k'!'su[..zF6V,V6rEtCO?&28nxs#k8z)\"\\6\\%TMxo:-sWVoim9gs',
                verification_code = '0',
                phone = '4'
            )
        else:
            return ApiVerificationCodesVerifyPostRequest(
                email = 'k@?x!u'K}qz^sEC)lJ*=-jQ+'6`%cClu,k'!'su[..zF6V,V6rEtCO?&28nxs#k8z)\"\\6\\%TMxo:-sWVoim9gs',
                verification_code = '0',
                phone = '4',
        )
        """

    def testApiVerificationCodesVerifyPostRequest(self):
        """Test ApiVerificationCodesVerifyPostRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Logto API references

    API references for Logto services. To learn more about how to interact with Logto APIs, see [Interact with Management API](https://docs.logto.io/docs/recipes/interact-with-management-api/).

    The version of the OpenAPI document: Cloud
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictFloat, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing_extensions import Annotated
from py_logto.models.api_sso_connectors_get200_response_inner_branding import ApiSsoConnectorsGet200ResponseInnerBranding
from typing import Optional, Set
from typing_extensions import Self

class ApiSsoConnectorsGet200ResponseInner(BaseModel):
    """
    ApiSsoConnectorsGet200ResponseInner
    """ # noqa: E501
    id: Annotated[str, Field(min_length=1, strict=True, max_length=128)]
    provider_name: StrictStr = Field(alias="providerName")
    connector_name: Annotated[str, Field(min_length=1, strict=True, max_length=128)] = Field(alias="connectorName")
    config: Dict[str, Any] = Field(description="arbitrary")
    domains: List[StrictStr]
    branding: ApiSsoConnectorsGet200ResponseInnerBranding
    sync_profile: StrictBool = Field(alias="syncProfile")
    created_at: Union[StrictFloat, StrictInt] = Field(alias="createdAt")
    name: StrictStr
    provider_type: StrictStr = Field(alias="providerType")
    provider_logo: StrictStr = Field(alias="providerLogo")
    provider_logo_dark: StrictStr = Field(alias="providerLogoDark")
    provider_config: Optional[Dict[str, Any]] = Field(default=None, alias="providerConfig")
    __properties: ClassVar[List[str]] = ["id", "providerName", "connectorName", "config", "domains", "branding", "syncProfile", "createdAt", "name", "providerType", "providerLogo", "providerLogoDark", "providerConfig"]

    @field_validator('provider_name')
    def provider_name_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(['OIDC', 'SAML', 'AzureAD', 'GoogleWorkspace', 'Okta', 'AzureAdOidc']):
            raise ValueError("must be one of enum values ('OIDC', 'SAML', 'AzureAD', 'GoogleWorkspace', 'Okta', 'AzureAdOidc')")
        return value

    @field_validator('provider_type')
    def provider_type_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(['oidc', 'saml']):
            raise ValueError("must be one of enum values ('oidc', 'saml')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ApiSsoConnectorsGet200ResponseInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of branding
        if self.branding:
            _dict['branding'] = self.branding.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ApiSsoConnectorsGet200ResponseInner from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "providerName": obj.get("providerName"),
            "connectorName": obj.get("connectorName"),
            "config": obj.get("config"),
            "domains": obj.get("domains"),
            "branding": ApiSsoConnectorsGet200ResponseInnerBranding.from_dict(obj["branding"]) if obj.get("branding") is not None else None,
            "syncProfile": obj.get("syncProfile"),
            "createdAt": obj.get("createdAt"),
            "name": obj.get("name"),
            "providerType": obj.get("providerType"),
            "providerLogo": obj.get("providerLogo"),
            "providerLogoDark": obj.get("providerLogoDark"),
            "providerConfig": obj.get("providerConfig")
        })
        return _obj





# coding: utf-8

"""
    Logto API references

    API references for Logto services. To learn more about how to interact with Logto APIs, see [Interact with Management API](https://docs.logto.io/docs/recipes/interact-with-management-api/).

    The version of the OpenAPI document: Cloud
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from py_logto.models.api_interaction_mfa_put_request import ApiInteractionMfaPutRequest

class TestApiInteractionMfaPutRequest(unittest.TestCase):
    """ApiInteractionMfaPutRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiInteractionMfaPutRequest:
        """Test ApiInteractionMfaPutRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiInteractionMfaPutRequest`
        """
        model = ApiInteractionMfaPutRequest()
        if include_optional:
            return ApiInteractionMfaPutRequest(
                type = '',
                code = '',
                id = '',
                raw_id = '',
                authenticator_attachment = 'cross-platform',
                client_extension_results = py_logto.models._api_interaction_bind_mfa_post_request_one_of_1_client_extension_results._api_interaction_bind_mfa_post_request_oneOf_1_clientExtensionResults(
                    appid = True, 
                    crep_props = py_logto.models._api_interaction_bind_mfa_post_request_one_of_1_client_extension_results_crep_props._api_interaction_bind_mfa_post_request_oneOf_1_clientExtensionResults_crepProps(
                        rk = True, ), 
                    hmac_create_secret = True, ),
                response = py_logto.models._api_interaction_mfa_put_request_one_of_response._api_interaction_mfa_put_request_oneOf_response(
                    client_data_json = '', 
                    authenticator_data = '', 
                    signature = '', 
                    user_handle = '', )
            )
        else:
            return ApiInteractionMfaPutRequest(
                type = '',
                code = '',
                id = '',
                raw_id = '',
                client_extension_results = py_logto.models._api_interaction_bind_mfa_post_request_one_of_1_client_extension_results._api_interaction_bind_mfa_post_request_oneOf_1_clientExtensionResults(
                    appid = True, 
                    crep_props = py_logto.models._api_interaction_bind_mfa_post_request_one_of_1_client_extension_results_crep_props._api_interaction_bind_mfa_post_request_oneOf_1_clientExtensionResults_crepProps(
                        rk = True, ), 
                    hmac_create_secret = True, ),
                response = py_logto.models._api_interaction_mfa_put_request_one_of_response._api_interaction_mfa_put_request_oneOf_response(
                    client_data_json = '', 
                    authenticator_data = '', 
                    signature = '', 
                    user_handle = '', ),
        )
        """

    def testApiInteractionMfaPutRequest(self):
        """Test ApiInteractionMfaPutRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
